from src.Pylite import Database,email,password,Table

db = Database("DataBase.pylite", "password",AutoSave=True)#.LoadFromSQL("test.db")
# db.Users.afterInsert = lambda table,added: print("Inserted",added)
# db.Users.Insert(ID = 1, Email = "ilies@gmail.com", Password = "passwordA1.")
print(db.Users[0])



# db = Database()
# db.CreateTable("Users").AddColumn(
#     ID = int,
#     Email = email,
#     Password = password
# )
# db.Users.afterInsert = lambda table,added: print("Inserted",added.Email)
# db.Save("DataBase.pylite", "password")



import re
import faker
class email(str):
    def __new__(cls, value):
        if not re.match(r"^((?!\.)[\w\-_.]*[^.])(@\w+)(\.\w+(\.\w+)?[^.\W])$", value, re.MULTILINE):
            raise ValueError("Invalid email")
        return super().__new__(cls, value)
    
    @staticmethod
    def fake():
        return faker.Faker().email()



class password(str):
    length = 8
    def __new__(cls, value):
        if len(value) < cls.length:
            raise ValueError(f"Password must be at least {cls.length} characters long")
        if not re.search(r"[A-Z]", value):
            raise ValueError("Password must contain at least one uppercase letter")
        if not re.search(r"[a-z]", value):
            raise ValueError("Password must contain at least one lowercase letter")
        if not re.search(r"[0-9]", value):
            raise ValueError("Password must contain at least one digit")
        if not re.search(r"[!@#$%^&*(),.?\":{}|<>]", value):
            raise ValueError("Password must contain at least one special character")
        return super().__new__(cls, value)
    
    @staticmethod
    def fake():
        fake = faker.Faker()
        return fake.password(length=12, special_chars=True, digits=True, upper_case=True, lower_case=True)

